@@ -7,26 +7,27 @@ class Neurone:
         self.x11 = 0
         self.x22 = 0
         self.b = 0
-        self.bw = 0
+        self.wb = 0
         self.rate = rate
         self.out = 0
         self.sumw = 0
     def sigmoid(self):
         self.out = (1 / (1 + exp(-self.sumw)))
     def wsum(self):
-        self.sumw = b * wb + (x11 * w11 + x22 * w22)
+        self.sumw = self.b * self.wb + (self.x11 * self.w11 + self.x22 * self.w22)
     def grlearn(self):
         self.w11 += self.rate
         self.w22 += self.rate
     def lineal_error(self, pred):
         self.error = self.out - pred
-    def train(self, inputs, preds, epochs = 300):
+    def train(self, inputs, pred, epochs = 300):
+        errors = []
         self.x11 = inputs[0]
         self.x22 = inputs[1]
-        for i in epochs:
+        for i in range(0, epochs):
             self.wsum()
             self.sigmoid()
-            self.lineal_error()
+            self.lineal_error(pred)
             errors.append(self.error)
             if self.error == 0:
                 break
